//
//  SKPaymentTransaction.h
//  StoreKit
//
//  Copyright 2009 Apple, Inc. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <StoreKit/StoreKitDefines.h>

@class SKPayment;

typedef NS_ENUM(NSInteger, SKPaymentTransactionState) {
    SKPaymentTransactionStatePurchasing,    // Transaction is being added to the server queue.
    SKPaymentTransactionStatePurchased,     // Transaction is in queue, user has been charged.  Client should complete the transaction.
    SKPaymentTransactionStateFailed,        // Transaction was cancelled or failed before being added to the server queue.
    SKPaymentTransactionStateRestored,      // Transaction was restored from user's purchase history.  Client should complete the transaction.
    SKPaymentTransactionStateDeferred NS_ENUM_AVAILABLE_IOS(8_0),   // The transaction is in the queue, but its final status is pending external action.
} NS_AVAILABLE_IOS(3_0);

SK_EXTERN_CLASS_AVAILABLE(3_0) @interface SKPaymentTransaction : NSObject {
@private
    id _internal;
}

// Only set if state is SKPaymentTransactionFailed
@property(nonatomic, readonly) NSError *error NS_AVAILABLE_IOS(3_0);

// Only valid if state is SKPaymentTransactionStateRestored.
@property(nonatomic, readonly) SKPaymentTransaction *originalTransaction NS_AVAILABLE_IOS(3_0);

@property(nonatomic, readonly) SKPayment *payment NS_AVAILABLE_IOS(3_0);

// Available downloads (SKDownload) for this transaction
@property(nonatomic, readonly) NSArray *downloads NS_AVAILABLE_IOS(6_0);

// The date when the transaction was added to the server queue.  Only valid if state is SKPaymentTransactionStatePurchased or SKPaymentTransactionStateRestored.
@property(nonatomic, readonly) NSDate *transactionDate NS_AVAILABLE_IOS(3_0);

// The unique server-provided identifier.  Only valid if state is SKPaymentTransactionStatePurchased or SKPaymentTransactionStateRestored.
@property(nonatomic, readonly) NSString *transactionIdentifier NS_AVAILABLE_IOS(3_0);

// Only valid if state is SKPaymentTransactionStatePurchased.
@property(nonatomic, readonly) NSData *transactionReceipt NS_DEPRECATED_IOS(3_0, 7_0, "Use -[NSBundle appStoreReceiptURL]");

@property(nonatomic, readonly) SKPaymentTransactionState transactionState NS_AVAILABLE_IOS(3_0);

@end
